@@ -45,7 +45,7 @@ pub fn new_state_on_path(
     con: &AppContext,
 ) -> CmdResult {
     let path = path::closest_dir(&path);
-    CmdResult::from_optional_state(
+    CmdResult::from_optional_browser_state(
         BrowserState::new(path, tree_options, screen, con, &Dam::unlimited()),
         None,
         false,
@@ -177,11 +177,13 @@ pub fn get_status_markdown(
 
 /// general implementation for verbs based on the :focus internal with optionally
 /// a bang or an argument.
+#[allow(clippy::too_many_arguments)]
 pub fn on_internal(
     internal_exec: &InternalExecution,
     input_invocation: Option<&VerbInvocation>,
     trigger_type: TriggerType,
     selected_path: &Path,
+    is_root_selected: bool,
     tree_options: TreeOptions,
     app_state: & AppState,
     cc: &CmdContext,
@@ -234,8 +236,15 @@ pub fn on_internal(
             } else {
                 // user only wants to open the selected path, either in the same panel or
                 // in a new one
-                on_path(selected_path.to_path_buf(), screen, tree_options, bang, con)
-            }
+                let mut path = selected_path.to_path_buf();
+                if !bang && is_root_selected {
+                    // the selected path is the root, focusing it would do nothing, so
+                    // we rather go up one level
+                    if let Some(parent_path) = selected_path.parent() {
+                        path = parent_path.to_path_buf();
+                    }
+                }
+                on_path(path, screen, tree_options, bang, con)}
         }
     }
 }
